package vc.thinker.absctacts.mqtt.protocol;


import akka.actor.ActorSystem;
import org.eclipse.paho.client.mqttv3.MqttClient;
import org.springframework.beans.factory.annotation.Autowired;
import vc.thinker.absctacts.mqtt.connection.MqttConnectionProperties;
import vc.thinker.absctacts.mqtt.publish.MqttCommandPush;
import vc.thinker.config.akka.extension.SpringExtension;

/**
 * 抽象的Mqtt协议
 *
 * @author HeTongHao
 * @since 2019-10-29 16:00
 */
public abstract class AbstractMqttProtocol implements IMqttProtocol {
    @Autowired
    protected ActorSystem actorSystem;
    @Autowired
    protected SpringExtension springExtension;

    protected final MqttConnectionProperties mqttConnectionProperties;

    /**
     * mqtt连接
     */
    private MqttClient mqttClient;
    /**
     * 默认mqtt推送组件
     */
    private MqttCommandPush mqttCommandPush;

    @Override
    public MqttConnectionProperties getProperties() {
        return mqttConnectionProperties;
    }

    public AbstractMqttProtocol(MqttConnectionProperties mqttConnectionProperties) {
        this.mqttConnectionProperties = mqttConnectionProperties;
    }

    @Override
    public void setMqttClient(MqttClient mqttClient) {
        this.mqttClient = mqttClient;
        this.mqttCommandPush = new MqttCommandPush(mqttClient);
    }

    @Override
    public MqttCommandPush getMqttCommandPush() {
        return mqttCommandPush == null ? mqttCommandPush = new MqttCommandPush(mqttClient) : mqttCommandPush;
    }

    /**
     * 处理消息
     *
     * @param topic   监听到消息的Topic
     * @param message 监听到的消息
     */
    @Override
    public abstract void handleMessage(String topic, byte[] message);
}
